import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.awt.Color;
import javax.swing.*;
/**
 * The ball of the game. It moves and bounces off the walls and the paddle.
 * 
 * @author mik
 * @version 1.0
 */
public class Ball extends Actor
{
    private int deltaX;         // x movement speed
    private int deltaY;         // y movement speed
    private int count = 2;// counter variable for the smoke
    private Counter points;
    private boolean stuck = true;   // stuck to paddle
    private Lives lives;
    private int blocksNumber = 30;
    public int level=1;
    public Ball(Counter score, Lives life)
    {
        points = score;
        lives = life;
        
    }

    public void addedToWorld(World w)
    {
        String tmp = getWorld().getClass().getName();
        tmp=tmp.substring(5);
        level=Integer.parseInt(tmp);
    }
    
    /**
     * Act. Move if we're not stuck.
     */
    public void act() 
    {
        if (!stuck) 
        {
            move();
            makeSmoke();
            checkBlock();
            // newLevel();
            checkWin();
            checkOut();

        }
    }

    private void checkBlock()
    {

        Actor block = getOneIntersectingObject(Block.class);
        if (block != null)
        {
            deltaY = -deltaY;
            points.addScore();
            getWorld().removeObject(block);
            blocksNumber--;
        }
    }

    /**
     * Move the ball. Then check what we've hit.
     */
    public void move()
    {
        setLocation(getX()+deltaX,getY()+deltaY);
        checkWalls();
        checkPaddle();
    }

    /**
     * Check whether we've hit one of the three walls. Reverse direction if necessary.
     */
    private void checkWalls()
    {
        if (getX() < 15|| getX() > getWorld().getWidth() - 15)
        {
            deltaX = -deltaX;
        }
        if (getY() <=15)
        {
            deltaY = -deltaY;
        }
    }

    /**
     * Check whether I am out (bottom of screen). If so, remove me from the world.
     */
    private void checkOut()
    {
        Board board = (Board)getWorld();
        if (getY()== board.getHeight()-5)
        {
            board.removeObject(this);
            board.ballIsOut();
            lives.addScore();

        }

    }

    /**
     * Did I hit the paddle? If so, bounce in the following fashion.
     * Reverse the y-direction.
     * The close I am to the middle of the paddle the more verticle my bounce.
     */
    private void checkPaddle()
    {
        Actor paddle = getOneIntersectingObject(Paddle.class);
        if (paddle != null)
        {
            deltaY = -deltaY;
            int offset = getX() - paddle.getX();
            deltaX = deltaX + offset/10;
        }
    }

    /**
     * Move the ball a given distance sideways.
     */
    public void move(int dist)
    {
        setLocation (getX() + dist, getY());

    }

    public void checkWin()
    {

        //if (getWorld().getObjects(Block.class).size()<2)
        if (getWorld().getObjects(Block.class).isEmpty())
        {
            level++; 
            switch (level)
            {
                case 2: Greenfoot.setWorld(new Level2(lives,points));
                
                break;
                
                case 3: Greenfoot.setWorld(new Level3(lives,points));
                
                break;
                
                case 4: Greenfoot.setWorld(new Level4(lives,points));
                
                break;
                
                case 5: Greenfoot.setWorld(new Level6(lives,points));
                
                break;
                
                case 6: Greenfoot.setWorld(new Level5(lives,points));
                
                break;
            }
          
            
            if (level > 6)
            {
                JOptionPane.showMessageDialog(null, "You win!");
                Greenfoot.stop();
            }
            
        }

    }

    /**
     * Put out a puff of smoke (only on every second call).
     */
    private void makeSmoke()
    {
        count --;
        if (count == 0)
        {
            getWorld().addObject(new Smoke(), getX(), getY());
            count = 1;
        }
    }

    /**
     * Release the ball from the paddle. deltaY is fixed, deltaX is random [-5, 5].
     */
    public void release()
    {
        deltaX = Greenfoot.getRandomNumber(11) - 5;
        deltaY = -5;
        stuck = false;

    }
}

// do //testing only
//{
//            deltaX = Greenfoot.getRandomNumber(11) - 5; 

//      }
//    while (deltaX == 0);
