import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * The game paddle. It is keyboard controlled (left, right, space). It also 
 * generates a new ball when it is created itself.
 * 
 * @author mik
 * @version 1.1
 */
public class Paddle extends Actor
{
    private Ball myBall;  // used before ball gets released
    private Counter score;
    private Lives life;
    public Paddle(Counter counter, Lives lives)
    {
        score = counter;
        life = lives;
    }

    /**
     * When the paddle gets created, create a ball as well.
     */
    public void addedToWorld(World world)
    {
        newBall();
    }

    /**
     * Act - do whatever the Paddle wants to do. This method is called whenever
     * the 'Act' or 'Run' button gets pressed in the environment.
     */
    public void act() 
    {
        if (Greenfoot.isKeyDown ("left")) 
        {
            moveSideways(-9);
        }
        if (Greenfoot.isKeyDown ("right")) 
        {
            moveSideways(9);
        }
        // If I have the ball and the "space" key is pressed, release the ball
        if (haveBall() && Greenfoot.isKeyDown ("space"))
        {
            releaseBall();
           
        }
    }

    /**
     * Move me in the horizontal direction.  If a ball is attached, move it also.
     */
    private void moveSideways(int dist)
    {
        setLocation(getX() + dist,getY());
        if (myBall!=null)
        {
            myBall.move(dist);
        }
    }

    /**
     * Create a new ball in the world and place it at the center of the paddle.
     */
    public void newBall()
    {
        myBall = new Ball(score, life);
        getWorld().addObject(myBall, getX(), getY()-20);
    }

    /**
     * If the ball has been released, return false, otherwise return true.
     */
    public boolean haveBall()
    {
        
        return myBall != null;
    }

    /**
     * Release the ball.  Tell the paddle the ball has been relaesed.
     */
    public void releaseBall()
    {
        myBall.release();
        myBall = null;
        
    }

}